..
    This file is part of Invenio.
    Copyright (C) 2019 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

What is Invenio Framework?
==========================

Invenio is an open source framework for building large-scale digital
repositories.

Invenio is first and foremost a source code framework. It's a framework that
you can use to build a repository solution, but it is not by itself a final
repository software. Using Invenio requires you to develop code.

If you're looking for a repository solution, checkout
`InvenioRDM <https://inveniosoftware.org/products/rdm>`_.

If you're looking for a Integrated Library System (ILS), checkout
`InvenioILS <https://inveniosoftware.org/products/ils>`_.

Several repositories have been built on top of Invenio v3, including e.g.:

- `Zenodo <https://zenodo.org>`_ - General purpose research data repository.
- `CERN Open Data <http://opendata.cern.ch>`_ - Open data repository for CERN.
- `CERN Videos <https://videos.cern.ch>`_ - Digital Assets Management system
  with video encoding support.

